==> liquidprompt_1.12.0.orig.tar.gz: liquidprompt-1.12.0/CONTRIBUTORS.md <==
# Contributors

Keeping this list in order of importance or size would be impossible, so it is
in order of least recent to most recent contribution.
We thank all our contributors, no matter the size of their contribution.

Please do not open a new issue or pull request just for adding yourself to
this file. If you made a contribution and got missed, please add a comment
on the issue or pull request of your contribution, and we will add it.

Thanks again to everyone for all of the help and support!

### Maintainers
* @nojhan (Original author)
* Olivier Mengué (@dolmen) (Former lead maintainer)
* Mark Vander Stel (@Rycieos) (Current lead maintainer)

### Code contributions
* @nojhan
* Yann 'Ze' Richard (@Zeuh)
* Aurélien Requiem (@aureq)
* François Schmidts (@jaesivsm)
* Joris Dedieu (@rmdir)
* Florian Le Frioux (@floweb)
* Ludovic Rousseau (@LudovicRousseau)
* Thomas Debesse <thomas.debesse@gmail.com>
* @Poil
* Michel Barret (@barmic)
* Luc Didry (@ldidry)
* Olivier Mengué (@dolmen)
* Alex Prengère (@alexprengere)
* Olivier Dupuis (@ojdupuis)
* Frédéric Lepied (@flepied)
* Christophe Drevet <christophe.drevet@cea.fr>
* Joris Vaillant (@jorisv)
* Étienne Deparis (@milouse)
* Clément Mathieu (@cykl)
* David Loureiro (@dloureiro)
* Nicolas Lacourte (@nlacourte)
* Jonas Bengtsson (@jonasb)
* Stéphane Pajot <pajot.stephane@gmail.com>
* Brad Beyenhof (@augmentedfourth)
* Julien Pecqueur (@jpec)
* Rolf Morel (@rolfmorel)
* Jean-Sébastien Leroy (@jsleroy)
* Joseph Bass (@jab416171)
* Ying Li (@cyli)
* Daniel Miranda (@danielkza)
* Brendan Fahy (@f4hy)
* Young King (@wayhome)
* Dustin Knie (@nullpuppy)
* @Cougar
* Octavian Damiean (@mainerror)
* Nicolas Pouillard (@np)
* Olivier Le Thanh Duong (@olethanh)
* Markus Dreseler (@mrks)
* Kim Lidström (@dxtr)
* Taahir Ahmed (@ahmedtd)
* Ryan Wilson-Perkin (@ryanwilsonperkin)
* George Macon (@gmacon)
* Anthony Gelibert (@anthonygelibert)
* @yannack
* Felix Chern (@dryman)
* Kyle P Davis (@KylePDavis)
* Alexander Belyaev (@alexbel)
* Cosmin L. Neagu (@clneagu)
* Brett McBride (@brettmc)
* Linus Wallgren (@ecksun)
* Matthew Micene (@nzwulfin)
* Panagiotis Kkolos (@pkkolos)
* Chase Colman (@chase)
* Wilson Maravilha (@wmv)
* Vincent Lara (@l-vincent-l)
* Bartosz Janda (@bartoszj)
* Morgan Knicely (@morganizeit)
* Austen Adler (@stonewareslord)
* Jonathan Giddy (@jongiddy)
* Jeremy Clement (@hexaJer)
* Samuel Krieg (@SamK)
* @hegedus
* Erik Jacobs (@thoraxe)
* Hagen Graf (@hcgraf)
* Tener Hades (@clayboone)
* Philipp Grogg (@gro-gg)
* @Hotschke
* Software Mechanic <softwaremechanic32@gmail.com>
* Simon McVittie (@smcv)
* Felix Schlitter (@felixSchl)
* Mark Vander Stel (@Rycieos)
* Philip Garrison (@pgarrison)
* Matt Smith (@ncs-msmith)
* @ste-fan
* Peter van Dijk (@Habbie)
* Nolan Leake (@nolanl)
* Dmitry V. Drozdovich (@thrushcat)
* Tristan Miller (@logological)
* Markus Gebert (@mgeb)
* Tore Anderson (@toreanderson)

### Code cleanup
* Aurélien Requiem (@aureq)
* Olivier Mengué (@dolmen)
* Roy Wellington Ⅳ (@thanatos)
* Roland van Laar (@rvanlaar)
* Nicolás Alvarez (@nicolas17)
* Frédéric Mahé (@frederic-mahe)
* Kevin Yap (@iKevinY)
* Matt Kelly (@mattkelly)
* Colin Lieberman (@colinlieberman)
* Bryce Jasmer (@b-jazz)

### Bug reports / Feature requests
* @skanx
* Yann 'Ze' Richard (@Zeuh)
* Michael Grosser (@grosser)
* Ludovic Rousseau (@LudovicRousseau)
* Matthias Bussonnier (@Carreau)
* Guillaume (@Gui13)
* Olivier Mengué (@dolmen)
* Alex Prengère (@alexprengere)
* @nojhan
* Lorenzo Leonini (@lleonini)
* @razcampagne
* Christophe Drevet-Droguet (@dr4Ke)
* David Loureiro (@dloureiro)
* Clément Mathieu (@cykl)
* Guillaume Denry (@Guid75)
* @gpapia
* Luc Didry (@ldidry)
* Mathieu Roche (@mathieuroche)
* Julien Pecqueur (@jpec)
* Loïc Guitaut (@Flink)
* @madmanu
* @quent57
* @vicnet
* Daniel Miranda (@danielkza)
* Brendan Fahy (@f4hy)
* Nicolas Pouillard (@np)
* Richard Hartmann (@RichiH)
* François Schmidts (@jaesivsm)
* Anthony Carathimas (@acgreek)
* Olivier Patry (@opatry)
* @manitooo
* Michael Cramer (@mikewebkist)
* Octavian Damiean (@mainerror)
* @Cougar
* Brad Beyenhof (@augmentedfourth)
* Florian Eitel (@nougad)
* Kyle P Davis (@KylePDavis)
* David Holm (@dholm)
* Pat Ramsey (@patramsey)
* Sébastien Sanoro (@dereckson)
* Taahir Ahmed (@ahmedtd)
* Emmett Butler (@emmett9001)
* Zak B. Elep (@zakame)
* André David (@adavidzh)
* @N-Mi
* @Cottser
* José Alberto (@jalberto)
* Guilherme Semente (@semente)
* Brad Clements (@bkc)
* Cosmin L. Neagu (@clneagu)
* Brett McBride (@brettmc)
* Andreas Böttger (@aboettger)
* Chase Colman (@chase)
* Stefan Wimmer (@wimstefan)
* Oliver Jan Krylow (@bugabinga)
* Chris Lasher (@gotgenes)
* @cato-
* Matt Fletcher (@MaffooBristol)
* Bartosz Janda (@bartoszj)
* Nicola Paolucci (@durdn)
* Jeremy Clement (@hexaJer)
* Brian May (@brianmay)
* Arturo Borrero Gonzalez (@aborrero)
* Toban Wiebe (@tobanw)
* Daniel Serodio (@dserodio)
* Peter VandeHaar (@pjvandehaar)
* Dave Rigby (@daverigby)
* Sebastian Bremicker (@sebrem)
* Simon McVittie (@smcv)
* Mark Vander Stel (@Rycieos)
* Jon Garrison (@jpwgarrison)
* Iain Hallam (@iainhallam)
* Mathias Picker (@mathiasp)
* Joey Liu (@liujoey)
* Florian Pigorsch (@flopp)
* Daniel Pinyol (@dpinol)
* Alyssa Ross (@alyssais)
* Gergo Szonyi (@gex)
* Nolan Leake (@nolanl)
* Éloi Rivard (@azmeuk)

==> liquidprompt_2.1.2.orig.tar.gz: liquidprompt-2.1.2/CONTRIBUTORS.md <==
# Contributors

Keeping this list in order of importance or size would be impossible, so it is
in order of least recent to most recent contribution.
We thank all our contributors, no matter the size of their contribution.

Please do not open a new issue or pull request just for adding yourself to
this file. If you made a contribution and got missed, please add a comment
on the issue or pull request of your contribution, and we will add it.

Thanks again to everyone for all of the help and support!

### Maintainers
* @nojhan (Original author)
* Olivier Mengué (@dolmen) (Former lead maintainer)
* Mark Vander Stel (@Rycieos) (Current lead maintainer)

### Code contributions
* @nojhan
* Yann 'Ze' Richard (@Zeuh)
* Aurélien Requiem (@aureq)
* François Schmidts (@jaesivsm)
* Joris Dedieu (@rmdir)
* Florian Le Frioux (@floweb)
* Ludovic Rousseau (@LudovicRousseau)
* Thomas Debesse <thomas.debesse@gmail.com>
* @Poil
* Michel Barret (@barmic)
* Luc Didry (@ldidry)
* Olivier Mengué (@dolmen)
* Alex Prengère (@alexprengere)
* Olivier Dupuis (@ojdupuis)
* Frédéric Lepied (@flepied)
* Christophe Drevet <christophe.drevet@cea.fr>
* Joris Vaillant (@jorisv)
* Étienne Deparis (@milouse)
* Clément Mathieu (@cykl)
* David Loureiro (@dloureiro)
* Nicolas Lacourte (@nlacourte)
* Jonas Bengtsson (@jonasb)
* Stéphane Pajot <pajot.stephane@gmail.com>
* Brad Beyenhof (@augmentedfourth)
* Julien Pecqueur (@jpec)
* Rolf Morel (@rolfmorel)
* Jean-Sébastien Leroy (@jsleroy)
* Joseph Bass (@jab416171)
* Ying Li (@cyli)
* Daniel Miranda (@danielkza)
* Brendan Fahy (@f4hy)
* Young King (@wayhome)
* Dustin Knie (@nullpuppy)
* @Cougar
* Octavian Damiean (@mainerror)
* Nicolas Pouillard (@np)
* Olivier Le Thanh Duong (@olethanh)
* Markus Dreseler (@mrks)
* Kim Lidström (@dxtr)
* Taahir Ahmed (@ahmedtd)
* Ryan Wilson-Perkin (@ryanwilsonperkin)
* George Macon (@gmacon)
* Anthony Gelibert (@anthonygelibert)
* @yannack
* Felix Chern (@dryman)
* Kyle P Davis (@KylePDavis)
* Alexander Belyaev (@alexbel)
* Cosmin L. Neagu (@clneagu)
* Brett McBride (@brettmc)
* Linus Wallgren (@ecksun)
* Matthew Micene (@nzwulfin)
* Panagiotis Kkolos (@pkkolos)
* Chase Colman (@chase)
* Wilson Maravilha (@wmv)
* Vincent Lara (@l-vincent-l)
* Bartosz Janda (@bartoszj)
* Morgan Knicely (@morganizeit)
* Austen Adler (@stonewareslord)
* Jonathan Giddy (@jongiddy)
* Jeremy Clement (@hexaJer)
* Samuel Krieg (@SamK)
* @hegedus
* Erik Jacobs (@thoraxe)
* Hagen Graf (@hcgraf)
* Tener Hades (@clayboone)
* Philipp Grogg (@gro-gg)
* @Hotschke
* Software Mechanic <softwaremechanic32@gmail.com>
* Simon McVittie (@smcv)
* Felix Schlitter (@felixSchl)
* Mark Vander Stel (@Rycieos)
* Philip Garrison (@pgarrison)
* Matt Smith (@ncs-msmith)
* @ste-fan
* Peter van Dijk (@Habbie)
* Nolan Leake (@nolanl)
* Dmitry V. Drozdovich (@thrushcat)
* Tristan Miller (@logological)
* Markus Gebert (@mgeb)
* Tore Anderson (@toreanderson)
* Fabien MARTY (@thefab)
* Alessio Garzi (@Ozzyboshi)
* Mathieu MD (@mathieumd)
* Romano Giannetti (@Rmano)
* Paulo Cazarotto (@phcco)
* Jürgen Weigert (@jnweiger)
* Sven-Hendrik Haase (@svenstaro)
* Sandro Jäckel (@SuperSandro2000)
* David Pape (@zyzzyxdonta)
* Aksel Sjögren (@akselsjogren)
* Raina Otoni (@rotoni)
* Munif Tanjim (@MunifTanjim)
* Martin Schütte (@mschuett)
* Sam Pearson (@sagepe)
* Ken Crowell (@oeuftete)
* Ian Smith (@ismith)
* Emil Lerch (@elerch)
* Michael Livshin (@cmm)
* Slobodan Todorov (@todorowww)
* Simon Chopin (@schopin-pro)
* @Mice7R
* Alan Hoyle (@alanhoyle)
* David Caro (@Terseus)
* Mark Korondi (@kmARC)
* Thomas Guimbretiere (@ProfMobius)
* Marco d'Itri (@rfc1036)

### Code cleanup
* Aurélien Requiem (@aureq)
* Olivier Mengué (@dolmen)
* Roy Wellington Ⅳ (@thanatos)
* Roland van Laar (@rvanlaar)
* Nicolás Alvarez (@nicolas17)
* Frédéric Mahé (@frederic-mahe)
* Kevin Yap (@iKevinY)
* Matt Kelly (@mattkelly)
* Colin Lieberman (@colinlieberman)
* Bryce Jasmer (@b-jazz)

### Documentation changes / clarifications
* Arturo Borrero Gonzalez (@aborrero)
* Brad Beyenhof (@augmentedfourth)
* John Hamelink (@johnhamelink)
* @YouthfulIndiscretion
* Imran Munshi (@imran27)
* Dugan Chen (@duganchen)
* Aleksey Tsalolikhin (@atsalolikhin-spokeo)
* Otto Kekäläinen (@ottok)

### Bug reports / Feature requests
* @skanx
* Yann 'Ze' Richard (@Zeuh)
* Michael Grosser (@grosser)
* Ludovic Rousseau (@LudovicRousseau)
* Matthias Bussonnier (@Carreau)
* Guillaume (@Gui13)
* Olivier Mengué (@dolmen)
* Alex Prengère (@alexprengere)
* @nojhan
* Lorenzo Leonini (@lleonini)
* @razcampagne
* Christophe Drevet-Droguet (@dr4Ke)
* David Loureiro (@dloureiro)
* Clément Mathieu (@cykl)
* Guillaume Denry (@Guid75)
* @gpapia
* Luc Didry (@ldidry)
* Mathieu Roche (@mathieuroche)
* Julien Pecqueur (@jpec)
* Loïc Guitaut (@Flink)
* @madmanu
* @quent57
* @vicnet
* Daniel Miranda (@danielkza)
* Brendan Fahy (@f4hy)
* Nicolas Pouillard (@np)
* Richard Hartmann (@RichiH)
* François Schmidts (@jaesivsm)
* Anthony Carathimas (@acgreek)
* Olivier Patry (@opatry)
* @manitooo
* Michael Cramer (@mikewebkist)
* Octavian Damiean (@mainerror)
* @Cougar
* Brad Beyenhof (@augmentedfourth)
* Florian Eitel (@nougad)
* Kyle P Davis (@KylePDavis)
* David Holm (@dholm)
* Pat Ramsey (@patramsey)
* Sébastien Sanoro (@dereckson)
* Taahir Ahmed (@ahmedtd)
* Emmett Butler (@emmett9001)
* Zak B. Elep (@zakame)
* André David (@adavidzh)
* @N-Mi
* @Cottser
* José Alberto (@jalberto)
* Guilherme Semente (@semente)
* Brad Clements (@bkc)
* Cosmin L. Neagu (@clneagu)
* Brett McBride (@brettmc)
* Andreas Böttger (@aboettger)
* Chase Colman (@chase)
* Stefan Wimmer (@wimstefan)
* Oliver Jan Krylow (@bugabinga)
* Chris Lasher (@gotgenes)
* @cato-
* Matt Fletcher (@MaffooBristol)
* Bartosz Janda (@bartoszj)
* Nicola Paolucci (@durdn)
* Jeremy Clement (@hexaJer)
* Brian May (@brianmay)
* Arturo Borrero Gonzalez (@aborrero)
* Toban Wiebe (@tobanw)
* Daniel Serodio (@dserodio)
* Peter VandeHaar (@pjvandehaar)
* Dave Rigby (@daverigby)
* Sebastian Bremicker (@sebrem)
* Simon McVittie (@smcv)
* Mark Vander Stel (@Rycieos)
* Jon Garrison (@jpwgarrison)
* Iain Hallam (@iainhallam)
* Mathias Picker (@mathiasp)
* Joey Liu (@liujoey)
* Florian Pigorsch (@flopp)
* Daniel Pinyol (@dpinol)
* Alyssa Ross (@alyssais)
* Gergo Szonyi (@gex)
* Nolan Leake (@nolanl)
* Éloi Rivard (@azmeuk)
* Felix Eckhofer (@tribut)
* Paul Lhussiez (@Depado)
* Cyril Bouthors (@cyril-bouthors)
* Felix Schlitter (@felixSchl)
* Christoph Burschka (@cburschka)
* @dreamcat4
* Munif Tanjim (@MunifTanjim)
* @ilovezfs
* Aleksey Tsalolikhin (@atsaloli)
* Micah Silverman (@dogeared)
* Rohan Kapadia (@kapad)
* Jan Gorecki (@jangorecki)
* Otto Kekäläinen (@ottok)
* Mike Simonson (@mikeSimonson)
* Viorel-Cosmin Miron (@uhlhosting)
* Dimitrie Hoekstra (@dimitrieh)
* Hynek Vychodil (@pichi)
* Ned Batchelder (@nedbat)
* Gary Wolfman (@OldCrow)
* @Orgams
* Andrei Matei (@andreimatei)
* Tiziano Santoro (@tiziano88)
* Michael Louis Thaler (@mithaler)
* Michael Große (@micgro42)
* Niko Storni (@nikooo777)
* Chris Weyl (@rsrchboy)
* Federico Stra (@FedericoStra)
* Roman (@hatifnatt)
* Alan Hoyle (@alanhoyle)
* Janne Himanka (@jhimanka)
* Peter van Dijk (@Habbie)
* Martin Blanchard (@t-chaik)
* François GUÉRIN (@frague59)
* Florian "KopfKrieg" (@KopfKrieg)
* @tsangal
